# Five One One

This is a collection of utility methods.

Install with:
`pip install -i https://test.pypi.org/simple/ five-one-one`

Import with:
`import five_one_one`

If you are building the module, use:
`python3 setup.py sdist bdist_wheel`

Upload with:
`twine upload --repository-url https://test.pypi.org/legacy/ dist/*`
